/****************************************************************************/
/*                                                                          */
/*  Xmenu  1998-2000 Jrme Grimbert                                       */
/*  -----                                                                   */
/*                                                                          */
/*  Jrme Grimbert remains the author and owner of this file and of all    */
/*  related works for the application of the copyright law and other rights.*/
/*  The use or distribution of this file proclaims the acceptation of this  */
/*  licence.                                                                */
/*  The use of this file and the relevant library is free, and at the risks */
/*  of the user.                                                            */
/*  This file and the relevant library can be distributed freely,           */
/*  at absolutely no cost.                                                  */
/*  Distribution on the internet is free and should never require any       */
/*  registration or identification when using the HTTP protocol.            */
/*  Ftp servers are free to offer access to this file and the related others*/
/*  files to all users, including the anonymous account.                    */
/*  Distribution with a charge may occur only with a prior written agreement*/
/*  between the distributor and Jrme Grimbert. In this particular case    */
/*  the distributor should expect to provide an absolutely free of charge   */
/*  copy of the media collection this file is included in. The exact        */
/*  definition of the collection is part of the negociation.                */
/*  In all case, the French laws and court rules will apply and prevail.    */
/*  The court of Versailles (France) will be the final referer.             */
/*                                                                          */
/*  Jrme Grimbert est l'auteur de ce fichier et de tout les fichiers qui  */
/*  y sont rattachs pour l'application de la convention de Berne et de la  */
/*  loi sur la proprit intellectuelle.                                    */
/*  L'usage ou la distribution de ce fichier entrane l'acceptation de      */
/*  cette license.                                                          */
/*  L'usage de ce fichier et des fichiers rattachs est libre, et aux       */
/*  risques et prils de l'utilisateur.                                     */
/*  La distribution est libre et gratuite.                                  */
/*  La distribution sur internet est libre et ne doit ncessiter aucun      */
/*  enregistrement ou identification lors de l'usage du protocole HTTP.     */
/*  Les serveurs FTP sont libres d'offrir l'accs  ce fichier ainsi qu'aux */
/*  fichiers y sont rattachs  tous les utilisateurs, y compris en accs   */
/*  anonyme.                                                                */
/*  Une distribution payante peut exister seulement avec un accord crit    */
/*  pralable entre le distributeur et Jrme Grimbert. Dans ce cas prcis  */
/*  le distributeur peut s'attendre  devoir fournir entirement            */
/*  gratuitement une copie de la collection dans laquelle se trouve ce      */
/*  fichier. La dfinition exacte du terme de collection fait partie de     */
/*  la ngociation.                                                         */
/*  Dans tout les cas, c'est la loi franaise qui s'appliquera et prvaudra.*/
/*  Le tribunal de Versailles (France) est le tribunal de rfrence.        */
/*                                                                          */
/*  Jrme Grimbert      ( au 01/08/1999 )                                  */
/*  1 Alle Louis Roveyaz                                                   */
/*  78140 Vlizy-Villacoublay                                               */
/*  France                                                                  */
/*                                                                          */
/*  jgrimbert@atos-group.com                                                */
/*                                                                          */
/****************************************************************************/

#ifndef XMENU
#define XMENU

#include <qptr.h>
#include "xmenudef_h"

/*
** Item_Select : color_code : for paper and ink
**               title      : a string that will be used as the title
**                            of the pop-up window
**               explanation: a string that explain the choice
**               nitem      : number of choice
**               ...        : a string, each one describing a possible
**                            choice.
**
** return value:
**               -1 : ESC was used to exit the window
**                n : choice number n was choosen
**
*/

long Item_Select(
                 const colourSet *   color_code,
                 const char *        title,
                 const char *        explanation,
                 const long          nitem,
                 const char *        litm0, ...
                );

/*
** Item_Select_Array : color_code : for paper and ink
**                     title      : a string that will be used as the title
**                                  of the pop-up window
**                     explanation: a string that explain the choice
**                     nitem      : number of choice
**                     array      : an array of strings, each one describing
**                                  a possible choice.
**
** return value:
**               -1 : ESC was used to exit the window
**                n : choice number n was choosen
**
*/

long Item_Select_Array(
                 const colourSet *   color_code,
                 const char *        title,
                 const char *        explanation,
                 const long          nitem,
                 const char **       array
                );

/*
** Message_Report : color_code : for paper and ink
**                  message    : a string to display as an item
**
*/

void Message_Report(
                    const colourSet *  color_code,
                    const char *       message
                   );

/*
** Startup_Report : color_code : for paper and ink
**                  message    : a string to display as an item
** Note : open a Primary
**
*/

void Startup_Report(
                    const colourSet *  color_code,
                    const char *       message
                   );


/*
** String_Edit : color_code     : for paper and ink
**               title          : a string that will be used as the title
**                                of the pop-up window
**               explanation    : a string that explain the entry
**               default_value  : a suggestion for the entry
**               max_length     : the maximal length of the entry
**               value          : the entry
**
** return value:
**               -1 : ESC was used to exit the window
**                n : the length of the entry
**
*/

long String_Edit(
                 const colourSet * color_code,
                 const char * title,
                 const char * explanation,
                 const char * default_value,
                 const long   max_length,
                       char * value
                );

/*
** XDialog : color_code  : for paper and ink
**           title       : a string that will be used as the title
**                         of the pop-up window
**           message     : a string that explain the choice
**           picture     : a logo to display on the left side of the message
**           help_avail  : null if no help option, not null if help option is available
**
** return value:
**               -1 : ESC was used to exit the window
**                0 : The ok option was choosen
**                1 : The cancel option was choosen
**                2 : The help option was choosen
**
*/

long XDialog(
             const colourSet * color_code,
             const char      * title,
             const char      * message,
             const struct WM_sprite * picture,
             const long        help_avail
            );

/*
** Menu_Button_Text : color_code  : for paper, ink and border
**                    main_window : the working main window that will be hidden
**                    title       : the text to use for the button
**
*/

void Menu_Button_Text(
                      const colourSet *       color_code,
                            struct WM_wwork * main_window,
                      const char *            title
                     );

/*
** Menu_Button_Logo : color_code  : for paper and border
**                    main_window : the working main window that will be hidden
**                    picture     : the sprite to use for the button
**
*/

void Menu_Button_Logo(
                      const colourSet *        color_code,
                            struct WM_wwork *  main_window,
                      const struct WM_sprite * picture
                     );

/*
** List_Select : color_code  : for paper and ink
**               title       : a string used as a title for the popup window
**               explanation : a text explaining the list
**               nitem       : the number of list items
**               status_list : the initial and final states of each item
**               ...         : a string, each describing a possible option
**
** return value:
**              number of selected items
**
*/

long List_Select(
                 const colourSet * color_code,
                 const char *      title,
                 const char *      explanation,
                 const long        nitem,
                       char *      status_list,
                 const char *      litm0, ...
                );

/*
** Radio_Select : color_code  : for paper and ink
**                initial     : initially set choice
**                title       : a string used as a title for the popup window
**                explanation : a text explaining the choice
**                nitem       : the number of radio buttons
**                initial     : the radio button initialy selected
**                ...         : a string, each describing a radio button
**
** return value:
**              -1 : ESC was used to exit the window
**              n  : on exit, radio button n was selected
**
*/
long Radio_Select(
                  const colourSet * color_code,
                  const long        initial,
                  const char *      title,
                  const char *      explanation,
                  const long        nitem,
                  const char *      litm0, ...
                 );

/*
** List_Select_Array : color_code  : for paper and ink
**                     title       : a string used as a title for the
**                                   popup window
**                     explanation : a text explaining the list
**                     nitem       : the number of list items
**                     status_list : the initial and final states of each item
**                     array       : an array of strings, each describing
**                                   a possible option
**
** return value:
**              number of selected items
**
*/

long List_Select_Array(
                 const colourSet * color_code,
                 const char *      title,
                 const char *      explanation,
                 const long        nitem,
                       char *      status_list,
                 const char **     array
                );

/*
** Radio_Select_Array : color_code  : for paper and ink
**                      initial     : initially set choice
**                      title       : a string used as a title for the
**                                    popup window
**                      explanation : a text explaining the choice
**                      nitem       : the number of radio buttons
**                      initial     : the radio button initialy selected
**                      array       : an array of strings, each describing
**                                    a radio button
**
** return value:
**              -1 : ESC was used to exit the window
**              n  : on exit, radio button n was selected
**
*/
long Radio_Select_Array(
                  const colourSet * color_code,
                  const long        initial,
                  const char *      title,
                  const char *      explanation,
                  const long        nitem,
                  const char **     array
                 );

/*
** Check_Size : window : the purported window definition
**
** return value:
**              0 : such a window can be drawn
**              !0 : such a window cannot be fitted on the current screen/application
**
*/
long Check_Size(
                const struct WM_wwork * window
               );

/*
** int Get_CharSize ()
**
** return value:
**               the width of a caracter in pixel, in the current mode
**               (6 for mode 4, 12 for mode 8)
**
*/
int Get_CharSize();

/*
** DefaultColourSet :
**
** return value:
**              a pointer to the default colour set (configurable via config)
*/
colourSet * DefaultColourSet(
              );


/*
** DisplayXsize
**
** return value: an unsigned int which is the max X value for the current display
**
*/
unsigned int DisplayXSize(
               );


/*
** DisplayYsize
**
** return value: an unsigned int which is the max Y value for the current display
**
*/
unsigned int DisplayYSize(
               );


/*
** SetWindowColour : ww  : the window definition
**                   col : the colour set to apply
**
*/

void SetWindowColour(struct WM_wwork * ww, colourSet * col);

/*
** SetInfoColour : info : the info window definition
**                 col  : the colour set to apply
**
*/

void SetInfoColour(struct WM_infw *info, colourSet * col);

/*
**
** LimitGeometry : ww   : the window definition
**                 maxX : the maximal width of the display
**                 maxY : the maximal heigth of the display
**
*/
void LimitGeometry(
                   struct WM_wwork * ww,
                   const unsigned int maxX,
                   const unsigned int maxY
                  );

/*
**
** Get_NativeForm()
**
** return value: an unsigned short which is the Form word for native sprite/blob/pattern
*/
unsigned short Get_NativeForm();

/*
**
** Get_GraphicInfo : sprite : a sprite definition
**                   pxsize : address of an unsigned short, will contain the x-size
**                   pysize : address of an unsigned short, will contain the y-size
**                   pxorg  : address of an unsigned short, will contain the x-org
**                   pyorg  : address of an unsigned short, will contain the y-org
*/
void Get_GraphicInfo(
                          const struct WM_sprite * picture,
                                unsigned short *xsize,
                                unsigned short *ysize,
                                unsigned short *xorg,
                                unsigned short *yorg,
                          );
/*
**
** xmenu_logo : a little (64x60) sprite, mode 4/8/33 (q40)
**
*/
extern struct WM_sprite xmenu_logo;

/*
** Radio_Range_Select : color_code  : for paper and ink
**                      initial     : initially set choice
**                      title       : a string used as a title for the
**                                    popup window
**                      explanation : a text explaining the choice
**                      mini        : the number on the minimal radio buttons
**                      maxi        : the number on the maximal radio buttons
**                      step        : the step between radio buttons
**
**
** return value:
**              -1 : ESC was used to exit the window
**               n : on exit, radio button n was selected
*/
long Radio_Range_Select(
                 const colourSet * color_code,
                 const long        initial,
                 const char *      title,
                 const char *      explanation,
                 const long        mini,
                 const long        maxi,
                 const long        step
                );

/*
** SmartHighColour : sprite : a sprite which has only Q40 or QXL high colour
**                   wanted : the current mode
**
*/
/*
void SmartHighColour(
                     struct WM_sprite * picture,
                     const unsigned short wanted
                    );
*/


#endif
